==============================================
Links to related open source software packages
==============================================

Here are a list of links to other useful sites or documents
which might be interesting if you are looking at ImageD11. No endorsement is
implied. Please send a pull request to add or remove links here.

Synchrotron + Multigrain
------------------------

https://github.com/FABLE-3DXRD/ (several sub-projects here)

https://sourceforge.net/projects/fable/

http://multigrain.texture.rocks/doku.php

https://sourceforge.net/projects/dct/

https://github.com/hexrd

https://github.com/praxes/hexrd

https://github.com/marinerhemant/MIDAS

https://github.com/MechanicsNext/MechanicsNext

https://github.com/MechanicsNext/MechanicsNext/wiki/MIDAS-Analysis-Workflow

https://github.com/HeLiuCMU/HEXOMAP

https://github.com/FrankieLi/IceNine

https://github.com/HeLiuCMU/nfHEDMtools

https://github.com/beamteamco/hedm-tools

https://github.com/haixingfang/LabDCT-forward-simu-model

https://github.com/pyxem/pyxem

https://github.com/junspark/matlab_tools

https://github.com/junspark/python_tools

https://github.com/rachelelim/diffraction_simulator

https://www.aps.anl.gov/files/APS-Uploads/SECTORS33-34/coordinates-PE-system.pdf

Modelling / Microstructures
----------------------------

https://github.com/BlueQuartzSoftware/DREAM3D

https://github.com/heprom/pymicro

https://github.com/rquey/neper

https://github.com/mrgprasad/kanapy

https://github.com/tdegeus/GooseFFT/

https://materialsdatafacility.org/

Pole figures / orientations
---------------------------

https://mtex-toolbox.github.io/

https://github.com/siddharth-maddali/snsampler

https://github.com/siddharth-maddali/SphereMesh

https://github.com/youngung/upf

General / physics / Crystallography
-----------------------------------

https://github.com/mantidproject/mantid

https://github.com/tschoonj/xraylib

https://github.com/silx-kit/silx

https://github.com/pmla/auguste

https://github.com/hua2001/PyStrucTrans

https://github.com/KedoKudo/cyxtal

http://ncorr.com/

https://github.com/yayahjb/bgaol

https://github.com/slaclab/psgeom

https://github.com/stefsmeets/xcore

https://github.com/McStasMcXtrace

IO/File formats
---------------

https://github.com/silx-kit/fabio

https://github.com/silx-kit/hdf5plugin

https://github.com/nexusformat

https://github.com/data-exchange/dxchange

https://github.com/kiyo-masui/bitshuffle

https://doi.org/10.1107/S2052252520008672 (IUCrJ Gold Standard paper)

https://github.com/yayahjb/cbflib

Powders and Rietveld
--------------------

https://github.com/silx-kit/pyFAI

https://subversion.xray.aps.anl.gov/trac/pyGSAS

https://github.com/tproffen/DiffuseCode

Electrons/ EBSD
---------------

https://github.com/BYU-MicrostructureOfMaterials/OpenXY

https://github.com/EMsoft-org/EMsoft

https://github.com/pyxem

https://github.com/stefsmeets/edtools

Tomo
----

https://github.com/astra-toolbox/astra-toolbox

https://github.com/tomopy/tomopy

https://gitlab.esrf.fr/tomotools

https://github.com/jcesardasilva/toupy

https://github.com/iternlm/microtomodenoise
